==> causality-0.0.10.tar.gz: causality-0.0.10/setup.py <==
from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='causality',

    version='0.0.10',

    description='Tools for causal inference',
    long_description=long_description,
    long_description_content_type='text/markdown',

    url='http://github.com/akelleh/causality',

    author='Adam Kelleher',
    author_email='akelleh@gmail.com',

    license='MIT',

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Scientific/Engineering',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
    ],

    keywords='causality data analysis inference causal graphs DAG propensity score matching',

    packages=find_packages(exclude=['tests']),

    install_requires=['numpy', 'scipy', 'pandas',
                      'statsmodels', 'networkx', 'patsy', 
                      'pytz', 'python-dateutil', 'decorator',
                      'pytz', 'six']
)

==> causality-0.0.11.tar.gz: causality-0.0.11/setup.py <==
from setuptools import setup, find_packages
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='causality',

    version='0.0.11',

    description='Tools for causal inference',
    long_description=long_description,
    long_description_content_type="text/markdown",
    url='http://github.com/akelleh/causality',

    author='Adam Kelleher',
    author_email='akelleh@gmail.com',

    license='MIT',

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Topic :: Scientific/Engineering :: Mathematics',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Bio-Informatics',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Scientific/Engineering',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7',
    ],

    keywords='causality data analysis inference causal graphs DAG propensity score matching',

    packages=find_packages(exclude=['tests']),

    install_requires=['numpy', 'scipy', 'pandas',
                      'statsmodels', 'networkx', 'patsy', 
                      'pytz', 'python-dateutil', 'decorator',
                      'pytz', 'six']
)
